import platform
import os
import re
import subprocess

from creatures.common import constants

"""
Utilities for opening dialogs.  This includes both functions for opening certain
types of dialogs as well as a general execute_dialog() function for opening
dialogs coded as external Python scripts. This is needed when using toolkits
such as PyQt and Pyglet that are not compatible.
"""

def get_cmd(file_name):
    if platform.system() == "Windows":
        return [file_name + ".exe"]
    else:
        return ["python", constants.DIALOG_DIR + os.sep + file_name + ".py"]

def show_tile_chooser_dialog(map_name):
    """
    Pop up a dialog that will allow the user to choose a tile on the given map.
    Returns either a tuple (col, row) or None if the user cancels the dialog.
    """
    cmd = get_cmd("tile_chooser_dialog")
    cmd.append(map_name)
    #cmd = ["python", constants.DIALOG_DIR + os.sep + "tile_chooser_dialog.py", map_name]
    regex = r"Selected (\d+) (\d+)"
    match = execute_dialog(cmd, regex)
    if match:
        col = int(match.group(1))
        row = int(match.group(2))
        return col, row
    return None

def show_open_map_dialog():
    """
    Pop up a dialog that will allow the user to select a map to open.
    Returns either the map name or None if the user cancels the dialog.
    """
    #cmd = ["python", constants.DIALOG_DIR + os.sep + "open_dialog.py", constants.MAP_DIR]
    cmd = get_cmd("open_dialog")
    cmd.append(constants.MAP_DIR)
    regex = r"Selected (.*" + "\\" + constants.MAP_EXTENSION + ")"
    match = execute_dialog(cmd, regex)
    if match:
        path = match.group(1)
        s = path.rfind("/")
        e = path.rfind(constants.MAP_EXTENSION)
        map_name = path[s + 1:e]
        return map_name
    return None

def show_save_map_dialog():
    """
    Pops up a dialog that will allow the user to select a map to open.
    Returns either the map name or None if the user cancels the dialog.
    """
    #cmd = ["python", constants.DIALOG_DIR + os.sep + "save_dialog.py", constants.MAP_DIR]
    cmd = get_cmd("save_dialog")
    cmd.append(constants.MAP_DIR)
    regex = r"Selected (.*" + "\\" + constants.MAP_EXTENSION + ")"
    match = execute_dialog(cmd, regex)
    if match:
        path = match.group(1)
        s = path.rfind("/")
        e = path.rfind(constants.MAP_EXTENSION)
        map_name = path[s + 1:e]
        return map_name
    return None

def execute_dialog(cmd, output_regex):
    """
    Executes the given command and searches the standard output using the given
    regex.  If a match is found, a match object is returned.  Otherwise, None
    is returned.
    """
    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    proc.wait()
    stdout, stderr = proc.communicate()
    match = re.search(output_regex, stdout)
    return match
