import sys

from collections import deque

from pyglet.window import key

from creatures.common import constants
from creatures.editor import drawing_utilities
from creatures.editor.map_renderer import EditorMapRenderer
from creatures.editor.widgets import TextButton

class TileChooserInterface(object):
    def __init__(self, key_handler, window_height, window_width, map_renderer):
        self.key_handler = key_handler
        self.window_height = window_height
        self.window_width = window_width

        self.map_renderer = map_renderer

        # None means the mouse has not been initialized
        self.mouse_x = None
        self.mouse_y = None

        self.mouse_clicked = False

        self.chosen_tile = None

        self.ok_button = TextButton(x = self.window_width - 10 - 300 - 20,
                                    y = 10 + 50,
                                    width = 150,
                                    height = 50,
                                    text = "Select",
                                    background = drawing_utilities.BLACK,
                                    disabled_background = drawing_utilities.GREY,
                                    border = drawing_utilities.RED,
                                    text_color = drawing_utilities.WHITE)

        self.cancel_button = TextButton(x = self.window_width - 10 - 150 - 10,
                                        y = 10 + 50,
                                        width = 150,
                                        height = 50,
                                        text = "Cancel",
                                        background = drawing_utilities.BLACK,
                                        border = drawing_utilities.RED,
                                        text_color = drawing_utilities.WHITE)

        self.ok_button.disable()

    def __call__(self, dt):
        self.update(dt)

    def update(self, dt):
        if self.key_handler[key.Q]:
            sys.exit()

        if self.key_handler[key.UP]:
            self.map_renderer.move_up()

        if self.key_handler[key.DOWN]:
            self.map_renderer.move_down()

        if self.key_handler[key.LEFT]:
            self.map_renderer.move_left()

        if self.key_handler[key.RIGHT]:
            self.map_renderer.move_right()

        if self.mouse_clicked:
            if self.ok_button.enabled and self.ok_button.is_clicked(self.mouse_x, self.mouse_y):
                print "Selected %s %s" % self.map_renderer.get_chosen_tile()
                sys.exit()
            elif self.cancel_button.is_clicked(self.mouse_x, self.mouse_y):
                print "Canceled"
                sys.exit()
            elif self.map_renderer.set_chosen_tile(self.mouse_x, self.mouse_y):
                self.ok_button.enable()
            self.clear_mouse_clicked()

    def draw_buttons(self):
        self.ok_button.draw()
        self.cancel_button.draw()

    def draw(self):
        # Order matters
        self.map_renderer.draw()
        self.draw_buttons()

    def set_mouse_position(self, x, y):
        self.mouse_x = x
        self.mouse_y = y
        self.map_renderer.set_current_tile(self.mouse_x, self.mouse_y)

    def set_mouse_clicked(self):
        self.mouse_clicked = True

    def clear_mouse_clicked(self):
        self.mouse_clicked = False
