from pyglet import gl
from pyglet import graphics

"""
Utilities for simple drawing functions such as drawing
empty and filled rectangles.  Also exports color constants.
"""

PURPLE = 204.0 / 255.0, 51.0 / 255.0, 204.0 / 255.0
ORANGE = 255.0 / 255.0, 140.0 / 255.0, 0.0 / 255.0
RED = 255.0 / 255.0, 0.0 / 255.0, 0.0 / 255.0
YELLOW = 255.0 / 255.0, 255.0 / 255.0, 0.0
BLUE = 0.0 / 255.0, 0.0 / 255.0, 255.0 / 255.0
GREEN = 0.0 / 255.0, 255.0 / 255.0, 0.0 / 255.0
WHITE = 255.0 / 255.0, 255.0 / 255.0, 255.0 / 255.0
BLACK = 0.0 / 255.0, 0.0 / 255.0, 0.0 / 255.0
GREY = 75.0 / 255.0, 75.0 / 255.0, 75.0 / 255.0

def draw_rectangle(color, x, y, width, height):
    """
    Draw an empty rectangle with the given border color,
    the lower left hand corner at x, y, and the specified
    width and height.
    """
    gl.glColor3f(*color)
    gl.glLineWidth(2)
    line_endings = (x, y,
                    x + width, y,
                    x + width, y,
                    x + width, y + height,
                    x + width, y + height,
                    x, y + height,
                    x, y + height,
                    x, y)
    graphics.draw(8, gl.GL_LINES, ("v2i", line_endings))

def draw_filled_rectangle(border, color, x, y, width, height):
    """
    Draw a filled rectangle with the given border color,
    a given fill color, the lower left hand corner at x, y,
    and the specified width and height.
    """
    gl.glColor3f(*color)
    gl.glLineWidth(2)
    line_endings = (x, y,
                    x + width, y,
                    x + width, y + height,
                    x, y + height)
    graphics.draw(4, gl.GL_QUADS, ("v2i", line_endings))
    draw_rectangle(border, x, y, width, height)
