import pyglet
from pyglet.sprite import Sprite


from creatures.editor import drawing_utilities
from creatures.common import geometry_utilities

"""
Implementations of Widgets such as buttons.
"""

class TextButton(object):
    """
    Models a push button with a text label.
    """
    def __init__(self, x=None, y=None, width=None, height=None, \
                     text=None, background=None, border=None, text_color=None, \
                     disabled_background=None):
        """
        x, y -- Coordinates of lower left corner
        """
        self.x = x
        self.y = y
        self.width = width
        self.height = height
        self.text = text
        self.background = background
        self.border = border
        # TODO: actually map color.  In the mean time, we're using different colors
        # for pyglet vs opengl so we ignore.
        self.text_color = text_color
        self.disabled_background = background
        if disabled_background:
            self.disabled_background = disabled_background

        self.label = pyglet.text.Label(self.text,
                                font_name = "Times New Roman",
                                font_size = 20,
                                x = self.x + self.width // 2,
                                y = self.y + self.height // 2,
                                anchor_x = "center",
                                anchor_y = "center")

        self.enabled = True

    def disable(self):
        self.enabled = False

    def enable(self):
        self.enabled = True

    def is_clicked(self, mouse_x, mouse_y):
        return geometry_utilities.point_in_box(mouse_x, mouse_y, \
                                                   self.x, self.y, \
                                                   self.width, self.height)

    def draw(self):
        if self.enabled:
            drawing_utilities.draw_filled_rectangle(self.border,
                                                self.background,
                                                self.x, self.y,
                                                self.width, self.height)
        else:
            drawing_utilities.draw_filled_rectangle(self.border,
                                                self.disabled_background,
                                                self.x, self.y,
                                                self.width, self.height)
        self.label.draw()

class ImageButton(object):
    """
    Models push button with image for label
    """
    def __init__(self, x=None, y=None, image=None, batch=None):
        self.x = x
        self.y = y
        self.width = image.width
        self.height = image.height

        self.sprite = Sprite(image, batch=batch)
        self.sprite.x = x
        self.sprite.y = y
        self.image = image

    def is_clicked(self, mouse_x, mouse_y):
        return geometry_utilities.point_in_box(mouse_x, mouse_y, \
                                                   self.x, self.y, \
                                                   self.width, self.height)

    def draw(self):
        self.sprite.draw()
