import argparse
import glob
import os
import sys

from PIL import Image

def main(args):
    parser = argparse.ArgumentParser(description="Place given images into single spritesheet.")
    parser.add_argument("columns", type=int, help="Number of images per row")
    parser.add_argument("output", type=str, help="Target image")
    parser.add_argument("input_dir", type=str, help="Source image dir")
    
    parsed_args = parser.parse_args(args)

    input_filenames = glob.glob(parsed_args.input_dir + os.sep + "*.*")

    input_images = []
    sizes = set()
    for filename in input_filenames:
        img = Image.open(filename)
        input_images.append(img)
        sizes.add(img.size)

    if len(sizes) != 1:
        print "Input images in " + parsed_args.input_dir + " are not all the same size!"
        sys.exit()

    h, w = img.size

    rows = len(input_images) // parsed_args.columns + min(1, len(input_images) % parsed_args.columns)
    cols = parsed_args.columns

    print parsed_args.output, len(input_filenames), len(input_images), rows, cols

    width = cols * w
    height = rows * h

    spritesheet = Image.new("RGBA", (width, height), (255, 255, 255, 0))
    #spritesheet_data = spritesheet.load()

    for i, img in enumerate(input_images):
        row = i // parsed_args.columns
        col = i % parsed_args.columns
        start_x = col * w
        start_y = row * h
        spritesheet.paste(img, (start_x, start_y))
        #img_data = img.load()
        #for j in xrange(w):
        #    for k in xrange(h):
        #        pixel = img_data[j, k]
        #        spritesheet_data[start_x + j, start_y + k] = pixel

    spritesheet.save(parsed_args.output)

if __name__ == "__main__":
    main(sys.argv[1:])
    
