import math
import random
import sys

import pyglet
from pyglet.gl import *
from pyglet.window import key

from creatures.common import constants
from creatures.common.tileset import TilesetFactory
from creatures.common.map_renderer import MapRendererFactory
from creatures.game.world import World

WINDOW_WIDTH = 1024
WINDOW_HEIGHT = 768

# create the window, but keep it offscreen until we are done with setup
window = pyglet.window.Window(WINDOW_WIDTH, WINDOW_HEIGHT, visible=False, caption="Creatures")

# centre the window on whichever screen it is currently on (in case of multiple monitors)
window.set_location(window.screen.width/2 - window.width/2, window.screen.height/2 - window.height/2)

# handle the window resize event
@window.event
def on_resize(width, height):
    glViewport(0, 0, width, height)

    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()
    # setup a fixed dimension orthographic projection
    # this avoids gameplay problems if the window resolution is changed
    glOrtho(0, WINDOW_WIDTH, 0, WINDOW_HEIGHT, -1, 1)
    glMatrixMode(GL_MODELVIEW)
    glLoadIdentity()

    # tell pyglet that we have handled the event, prevents the default handler from running
    return pyglet.event.EVENT_HANDLED

# setup a key handler to track keyboard input
keymap = pyglet.window.key.KeyStateHandler()
window.push_handlers(keymap)

# clear the window and draw the scene
@window.event
def on_draw():
    window.clear()
    world.draw()


# clear and flip the window, otherwise we see junk in the buffer before the first frame
window.clear()
window.flip()

# make the window visible at last
window.set_visible(True)

# update callback
key_handler = key.KeyStateHandler()
window.push_handlers(key_handler)

# load tile sets and create game objects
tileset_factory = TilesetFactory(constants.IMAGE_DIR, constants.TILESETS)
map_renderer_factory = MapRendererFactory(tileset_factory)
if len(sys.argv) > 1:
  world = World(key_handler, WINDOW_HEIGHT, WINDOW_WIDTH, map_renderer_factory, map_name=sys.argv[1])
else:
  world = World(key_handler, WINDOW_HEIGHT, WINDOW_WIDTH, map_renderer_factory)
world.draw()

# schedule the update function, 30 times per second
pyglet.clock.schedule_interval(world, 1.0/30.0)


# finally, run the application
pyglet.app.run()
